package cron

import (
	"encoding/json"
	"log"
	"net/http"
	"strconv"

	"github.com/kilgaloon/leprechaun/api"
	"github.com/kilgaloon/leprechaun/daemon"
)

// this section is used for command responders

func (c *Cron) cmdinfo(w http.ResponseWriter, r *http.Request) {
	recipeQueueNum := strconv.Itoa(len(c.Service.Entries()))

	resp := api.InfoResponse{
		Status:         c.GetStatus().String(),
		RecipesInQueue: recipeQueueNum,
	}

	w.WriteHeader(http.StatusOK)

	j, err := json.Marshal(resp)
	if err != nil {
		log.Fatal(err)
	}

	w.Write(j)

	return
}

func (c *Cron) cmdpause(w http.ResponseWriter, r *http.Request) {
	resp := api.MessageResponse{}

	c.Pause()
	if c.GetStatus() == daemon.Paused {
		w.WriteHeader(http.StatusOK)
		resp.Message = "Server paused"
	} else {
		w.WriteHeader(http.StatusExpectationFailed)
		resp.Message = "Server failed to pause"
	}

	j, err := json.Marshal(resp)
	if err != nil {
		log.Fatal(err)
	}

	w.Write(j)
}

func (c *Cron) cmdstart(w http.ResponseWriter, r *http.Request) {
	resp := api.MessageResponse{}

	if c.GetStatus() == daemon.Started {
		w.WriteHeader(http.StatusExpectationFailed)
		resp.Message = "Server already started"
	}

	go c.Start()
	if c.GetStatus() == daemon.Started {
		w.WriteHeader(http.StatusOK)
		resp.Message = "Server started"
	} else {
		w.WriteHeader(http.StatusExpectationFailed)
		resp.Message = "Server failed to start"
	}

	j, err := json.Marshal(resp)
	if err != nil {
		log.Fatal(err)
	}

	w.Write(j)
}

func (c *Cron) cmdstop(w http.ResponseWriter, r *http.Request) {
	resp := api.MessageResponse{}

	c.Stop()
	if c.GetStatus() == daemon.Stopped {
		w.WriteHeader(http.StatusOK)
		resp.Message = "Server stopped"
	} else {
		w.WriteHeader(http.StatusExpectationFailed)
		resp.Message = "Server failed to stop"
	}

	j, err := json.Marshal(resp)
	if err != nil {
		log.Fatal(err)
	}

	w.Write(j)
}
